@@ -3,14 +3,14 @@
 # documentation at end of file
 
 use strict;
-use Getopt::Long;
+use Getopt::Long qw(:config no_ignore_case bundling);
 use Pod::Usage;
 use Bio::ToolBox::db_helper qw(
 	open_db_connection
 );
 use Bio::ToolBox::Data;
 use Bio::ToolBox::utility;
-my $VERSION = '1.52';
+my $VERSION = '1.60';
 
 print "\n This script will collect information for a list of features\n\n";
 
@@ -43,14 +43,14 @@ my (
 
 # Command line options
 GetOptions( 
-	'in=s'     => \$infile, # input file
-	'attrib=s' => \$attrib_request, # attribute
-	'out=s'    => \$outfile, # output filename
-	'db=s'     => \$database, # database name
-	'type=s'   => \$use_type, # force a type
-	'gz!'      => \$gz, # gzip status
-	'help'     => \$help, # help
-	'version'  => \$print_version, # print the version
+	'i|in=s'     => \$infile, # input file
+	'a|attrib=s' => \$attrib_request, # attribute
+	'o|out=s'    => \$outfile, # output filename
+	'd|db=s'     => \$database, # database name
+	't|type=s'   => \$use_type, # force a type
+	'z|gz!'      => \$gz, # gzip status
+	'h|help'     => \$help, # help
+	'v|version'  => \$print_version, # print the version
 ) or die " unrecognized option(s)!! please refer to the help documentation\n\n";
 
 
@@ -666,21 +666,25 @@ __END__
 
 get_feature_info.pl
 
-A script to collect feature information from a BioPerl SeqFeature::Store db.
+A program to collect feature information from a BioPerl SeqFeature::Store db.
 
 =head1 SYNOPSIS
 
 get_feature_info.pl <filename> 
 
-  Options:
-  --in <filename> 
-  --db <name>
-  --attrib <attribute1,attribute2,...>
-  --type <primary_tag>
-  --out <filename>
-  --gz
-  --version
-  --help
+  File options:
+  -i --in <filename>                        input file of list db features
+  -o --out <filename>                       optional output file
+  
+  Database options:
+  -d --db <name>                            annotation database: mysql sqlite
+  -a --attrib <attribute1,attribute2,...>   list of attributes to collect
+  -t --type <primary_tag>                   specify a feature type as needed
+  
+  General options:
+  -z --gz                                   compress output file
+  -v --version                              print version and exit
+  -h --help                                 show extended documentation
   
   Attributes include:
    Chromosome
@@ -709,9 +713,11 @@ get_feature_info.pl <filename>
 
 The command line flags and descriptions:
 
+=head2 File options
+
 =over 4
 
-=item --in <filename>
+=item --in E<lt>filenameE<gt>
 
 Specify an input file containing either a list of database features or 
 genomic coordinates for which to collect data. The file should be a 
@@ -720,7 +726,18 @@ feature identifiers, attributes, coordinates, and/or data values. The
 first row should be column headers. Text files generated by other 
 B<BioToolBox> scripts are acceptable. Files may be gzipped compressed.
 
-=item --db <name>
+=item --out E<lt>filenameE<gt>
+
+Optionally specify an alternate output file name. The default is to 
+overwrite the input file.
+
+=back
+
+=head2 Database options
+
+=over 4
+
+=item --db E<lt>nameE<gt>
 
 Specify the name of a C<Bio::DB::SeqFeature::Store> annotation database 
 from which gene or feature annotation may be derived. A database is 
@@ -728,49 +745,74 @@ required for generating new data files with features. For more information
 about using annotation databases, 
 see L<https://code.google.com/p/biotoolbox/wiki/WorkingWithDatabases>. 
 
-=item --attrib <attribute>
+=item --attrib E<lt>attributeE<gt>
 
 Specify the attribute to collect for each feature. Standard GFF attributes 
 may be collected, as well as values from specific group tags. These tags 
 are found in the group (ninth) column of the source GFF file. Standard 
 attributes include the following
-   
-   - Chromosome
-   - Start
-   - Stop
-   - Strand
-   - Score
-   - Name
-   - Alias
-   - Note
-   - Type
-   - Primary_tag
-   - Source
-   - Length
-   - Midpoint
-   - Phase
-   - RNA_count (number of transcript subfeatures)
-   - Exon_count (number of exon subfeatures)
-   - Gene_length (sum of all merged, collapsed, transcript exon lengths)
-   - Transcript_length (sum of exon lengths)
-   - Parent (name)
-   - Primary_ID
-   - <tag>
+
+=over 4
+ 
+=item * Chromosome
+
+=item * Start
+
+=item * Stop
+
+=item * Strand
+
+=item * Score
+
+=item * Name
+
+=item * Alias
+
+=item * Note
+
+=item * Type
+
+=item * Primary_tag
+
+=item * Source
+
+=item * Length
+
+=item * Midpoint
+
+=item * Phase
+
+=item * RNA_count (number of transcript subfeatures)
+
+=item * Exon_count (number of exon subfeatures)
+
+=item * Gene_length (sum of all merged, collapsed, transcript exon lengths)
+
+=item * Transcript_length (sum of exon lengths)
+
+=item * Parent (name)
+
+=item * Primary_ID
+
+=item * <tag>
+
+=back
 
 If attrib is not specified on the command line, then an interactive list 
 will be presented to the user for selection. Especially useful when you 
 can't remember the feature's tag keys in the database.
    
-=item --type <primary_tag>
+=item --type E<lt>primary_tagE<gt>
 
 When the input file does not have a type column, a type or primary_tag 
 may be provided. This is especially useful to restrict the database 
 search when there are multiple features with the same name.
 
-=item --out <filename>
+=back
 
-Optionally specify an alternate output file name. The default is to 
-overwrite the input file.
+=head2 General options
+
+=over 4
 
 =item --gz
 
